@@ -71,3 +71,8 @@ class DescribeCheckWarningsRequest(RpcRequest):
 
 	def set_RiskId(self, RiskId):  # Long
 		self.add_query_param('RiskId', RiskId)
+	def get_RiskStatus(self): # Integer
+		return self.get_query_params().get('RiskStatus')
+
+	def set_RiskStatus(self, RiskStatus):  # Integer
+		self.add_query_param('RiskStatus', RiskStatus)
