@@ -25,32 +25,29 @@ class DescribeStrategyRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'Sas', '2018-12-03', 'DescribeStrategy')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_SourceIp(self):
+	def get_SourceIp(self): # String
 		return self.get_query_params().get('SourceIp')
 
-	def set_SourceIp(self,SourceIp):
-		self.add_query_param('SourceIp',SourceIp)
-
-	def get_Lang(self):
+	def set_SourceIp(self, SourceIp):  # String
+		self.add_query_param('SourceIp', SourceIp)
+	def get_Lang(self): # String
 		return self.get_query_params().get('Lang')
 
-	def set_Lang(self,Lang):
-		self.add_query_param('Lang',Lang)
-
-	def get_CustomType(self):
+	def set_Lang(self, Lang):  # String
+		self.add_query_param('Lang', Lang)
+	def get_CustomType(self): # String
 		return self.get_query_params().get('CustomType')
 
-	def set_CustomType(self,CustomType):
-		self.add_query_param('CustomType',CustomType)
-
-	def get_StrategyIds(self):
+	def set_CustomType(self, CustomType):  # String
+		self.add_query_param('CustomType', CustomType)
+	def get_StrategyIds(self): # String
 		return self.get_query_params().get('StrategyIds')
 
-	def set_StrategyIds(self,StrategyIds):
-		self.add_query_param('StrategyIds',StrategyIds)
\ No newline at end of file
+	def set_StrategyIds(self, StrategyIds):  # String
+		self.add_query_param('StrategyIds', StrategyIds)
